==> flutter_conscent_plugin-0.3.0.tar.gz: lib/webviews.dart <==
import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
//import 'package:flutter_new/e';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'ConscentInitializer.dart';
import 'ConscentMethods.dart';
import 'Model/APIMode.dart';
import 'Model/loginChallengeget.dart';

//import 'package:pull_to_refresh/pull_to_refresh.dart';

void main() {
  runApp(
    MaterialApp(
      home: WebViewApps(isWoman: true),
    ),
  );
}

class WebViewApps extends StatefulWidget {
  String tiersId;
  bool isWoman;

  WebViewApps({this.tiersId = '', required this.isWoman, super.key});

  @override
  State<WebViewApps> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewApps> {
  String? loginId;
  String ar = "availFreeTrial=true%20";
  late String fn;

  late WebViewController _webViewController;

  final GlobalKey<RefreshIndicatorState> _refreshIndicatorKey =
      GlobalKey<RefreshIndicatorState>();

  final webViewKey = GlobalKey<_WebViewAppStates>();

  //var refreshKey = GlobalKey<RefreshIndicatorState>();

  // Add from here ...
  @override
  void initState() {
    _refreshIndicatorKey.currentState?.show();
    icon:
    const Icon(Icons.refresh);
    if (mounted) {
      getLoginChallengeId();
      print(widget.tiersId);
      print("tiersId");
    }
    print('---initState---${widget.tiersId}');

    if (widget.isWoman) {
      fn = ar;
    } else {
      fn = "";
    }

    super.initState();
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('WebViewApp sessionId ${prefs.getString('sessionId')}');
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      print(loginChallengeget.toJson());
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  // dynamic dataMains;
  Future<void> getPstss(String sessionId) async {
    final prefs = await SharedPreferences.getInstance();

    print('sessionId xyz------------------= $sessionId');

    sessionId = prefs.getString('sessionId') ?? "sessionId";
    print('--------print sessionnsss IDss-----------------');
    print(prefs.getString('sessionId'));
    String sessionIds = prefs.getString('sessionId').toString();

    final uri = Uri.parse(
        '${APIMode.BASE_URL}api/v1/subscription/access?sessionId=$sessionId&clientId=${ConscentInitializer.mClientId}');
    print(uri);
    print('session urllsssss --------------- ftttt');
    var response = await http.get(uri);

    print('---- status---${response.statusCode}');
    if (response.statusCode == 200) {
      print("dataMains -------------- dataaa");
      print("dataMains-------- dat-------------");
      var responseString = response.body;
      //   Navigator.pop(context,{
      // //    "sessionId":dataMain['sessionId']
      //     "response":responseString
      //   });

      if (mounted) {
        Navigator.pop(context, {
          "response": responseString
          // "sessionId":dataMain['sessionId']
        });
      }
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            getPstss(sessionId);
          } else if (message.message == 'changeplan') {
            CircularProgressIndicator();
            Navigator.pop(context);
          }
        });
  }

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    var flutterWebViewPlugin;
    print(loginId);
    print('sessionn-----------------id----------');
    print(widget.tiersId);
    print("tierssssIdd");

    print('kunallllllll');

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
        actions: <Widget>[
          TextButton.icon(
            onPressed: () {
              getLoginChallengeId();
              body:
              WebView(
                initialUrl:
                    '${APIMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${APIMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                javascriptMode: JavascriptMode.unrestricted,
                onWebViewCreated: (controller) {
                  _webViewController = controller;
                  controller.reload();
                },
                onProgress: (int progress) {
                  print('WebView is loading (progress : $progress%)');
                },
                navigationDelegate: (NavigationRequest request) {
                  if (request.url.startsWith('https://www.youtube.com/')) {
                    print('blocking navigation to $request}');
                    return NavigationDecision.prevent;
                  }
                  print('allowing navigation to $request');
                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {
                  print('Page started loading: $url');
                },
                onPageFinished: (String url) {
                  print('Page finished loading: $url');
                },
                gestureNavigationEnabled: true,
                backgroundColor: const Color(0x00000000),
              );
              webViewKey.currentState?.reloadWebView();
              // _webViewController?.reload();
              _refreshIndicatorKey.currentState?.show();
            },
            icon: const Icon(
              Icons.refresh,
              size: 24.0,
              color: Colors.white,
            ),
            label: const Text(''),
          ),
        ],
      ),
      body: RefreshIndicator(
        key: _refreshIndicatorKey,
        color: Colors.white,
        backgroundColor: Colors.blue,
        strokeWidth: 4.0,
        onRefresh: () async {
          return Future<void>.delayed(const Duration(seconds: 3));
        },
        child: loginId != null
            ? WebView(
                initialUrl:

                    //     'https://conscent.netlify.app/subscription?tierId=619b7f6cfbacc96bd8fb232a&clientId=5f92a62013332e0f667794dc&availFreeTrial=true%20&siteUrl=https://conscentsss.com&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                    '${APIMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${APIMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                // 'https://conscent.netlify.app/subscription?tierId=${widget.tiersId}&clientId=5f92a62013332e0f667794dc&siteUrl=https://conscentsss.com&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',

                javascriptMode: JavascriptMode.unrestricted,

                onProgress: (int progress) {
                  javascriptChannels:
                  <JavascriptChannel>{_javascriptChannel()};
                  print('WebView is loading (progress : $progress%)');
                },

                navigationDelegate: (NavigationRequest request) {
                  print('allowing navigation to $request');

                  if (request.url.startsWith(
                      '${APIMode.SERVICE_BASE_URL}/${ConscentInitializer.mClientId}')) {
                    getSessionID(loginId!);
                    //   getPstss(sessionId);
                    return NavigationDecision.prevent;
                  } else if (request.url.startsWith(
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})')) {
                    print('change plan');
                    Navigator.pop(context);
                    // Navigator.push(
                    //   context,
                    //   MaterialPageRoute(
                    //     builder: (context) => Subscribe((value){}),
                    //   ),
                    // );
                  }

                  print('GET URLLLLLWWWW: $request.url');
                  if (request.url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    print('change planss');
                    Navigator.pop(context);
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {
                  print('Page started loading: $url');
                  print(url);
                  // debugPrint ('Try');

                  print('GET URLLLLL: $url');
                  if (url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    print('change planss');
                    debugPrint('Try');
                    print(url);
                    Navigator.pop(context);
                  }
                },

                onPageFinished: (String url) {
                  print('Page finished loading: $url');
                  print('urllllllllllllllllllll: $url');

                  print('GET URLLLLLSSS: $url');
                  if (url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    print('change planss');
                    debugPrint('Try');
                    print(url);
                    Navigator.pop(context);
                  }
                },
                //  javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
                javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
              )
            : Center(child: CircularProgressIndicator()),
      ),
    );
  }

  void reloadWebView() {
    _webViewController.reload();
  }
}

==> flutter_conscent_plugin-0.3.6.tar.gz: lib/webviews.dart <==
import 'dart:async';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'dart:io' show Platform;

import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';


void main() {
  runApp(
    MaterialApp(
      home: WebViewApps(isWoman: true),
    ),
  );
}

class WebViewApps extends StatefulWidget {
  String tiersId;
  bool isWoman;

  WebViewApps({this.tiersId = '', required this.isWoman, super.key});

  @override
  State<WebViewApps> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewApps> {
  String? loginId;
  String ar = "availFreeTrial=true%20";
  late String fn;

  late WebViewController _webViewController;

  final GlobalKey<RefreshIndicatorState> _refreshIndicatorKey =
      GlobalKey<RefreshIndicatorState>();

  final webViewKey = GlobalKey<_WebViewAppStates>();

  //var refreshKey = GlobalKey<RefreshIndicatorState>();

  // Add from here ...
  @override
  void initState() {
    _refreshIndicatorKey.currentState?.show();
    icon:
    const Icon(Icons.refresh);
    if (mounted) {
      getLoginChallengeId();

    }


    if (widget.isWoman) {
      fn = ar;
    } else {
      fn = "";
    }

    super.initState();
  }

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');

    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {

    var uri = Uri.parse('${ApiMode.BASE_URL}api/v1/login-challenge/$loginId');

    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();

      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);

      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  // dynamic dataMains;
  Future<void> getPstss(String sessionId) async {
    final prefs = await SharedPreferences.getInstance();


    sessionId = prefs.getString('sessionId') ?? "sessionId";

    String sessionIds = prefs.getString('sessionId').toString();

    final uri = Uri.parse(
        '${ApiMode.BASE_URL}api/v1/subscription/access?sessionId=$sessionId&clientId=${ConscentInitializer.mClientId}');

    var response = await http.get(uri);


    if (response.statusCode == 200) {

      var responseString = response.body;


      if (mounted) {
        Navigator.pop(context, {
          "response": responseString
          // "sessionId":dataMain['sessionId']
        });
      }
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {

    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            String sessionId = await getSessionID(loginId!);
            getPstss(sessionId);
          } else if (message.message == 'changeplan') {
            const CircularProgressIndicator();
            Navigator.pop(context);
          }
        });
  }

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};

    String? userAgent = Constants.userAgent;

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
        actions: <Widget>[
          TextButton.icon(
            onPressed: () {
              getLoginChallengeId();
              WebView(
                initialUrl:
                    '${ApiMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${ApiMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                javascriptMode: JavascriptMode.unrestricted,
                userAgent: Platform.isIOS
                    ? '${userAgent!} Safari/605.1'
                    : userAgent?.replaceAll("; wv", ""),
                onWebViewCreated: (controller) {
                  _webViewController = controller;
                  controller.reload();
                },
                onProgress: (int progress) {

                },
                navigationDelegate: (NavigationRequest request) {
                  if (request.url.startsWith('https://www.youtube.com/')) {

                    return NavigationDecision.prevent;
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {

                },
                onPageFinished: (String url) {

                },
                gestureNavigationEnabled: true,
                backgroundColor: const Color(0x00000000),
              );
              webViewKey.currentState?.reloadWebView();
              // _webViewController?.reload();
              _refreshIndicatorKey.currentState?.show();
            },
            icon: const Icon(
              Icons.refresh,
              size: 24.0,
              color: Colors.white,
            ),
            label: const Text(''),
          ),
        ],
      ),
      body: RefreshIndicator(
        key: _refreshIndicatorKey,
        color: Colors.white,
        backgroundColor: Colors.blue,
        strokeWidth: 4.0,
        onRefresh: () async {
          return Future<void>.delayed(const Duration(seconds: 3));
        },
        child: loginId != null
            ? WebView(
                initialUrl:

                    //     'https://conscent.netlify.app/subscription?tierId=619b7f6cfbacc96bd8fb232a&clientId=5f92a62013332e0f667794dc&availFreeTrial=true%20&siteUrl=https://conscentsss.com&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                    '${ApiMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${ApiMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                // 'https://conscent.netlify.app/subscription?tierId=${widget.tiersId}&clientId=5f92a62013332e0f667794dc&siteUrl=https://conscentsss.com&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',

                javascriptMode: JavascriptMode.unrestricted,

                onProgress: (int progress) {
                  <JavascriptChannel>{_javascriptChannel()};
                },

                navigationDelegate: (NavigationRequest request) {

                  if (request.url.startsWith(
                      '${ApiMode.SERVICE_BASE_URL}/${ConscentInitializer.mClientId}')) {
                    getSessionID(loginId!);
                    //   getPstss(sessionId);
                    return NavigationDecision.prevent;
                  } else if (request.url.startsWith(
                      '${ApiMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})')) {

                    Navigator.pop(context);

                  }

                  if (request.url ==
                      '${ApiMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {

                    Navigator.pop(context);
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {
                  if (url == '${ApiMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {

                    Navigator.pop(context);
                  }
                },

                onPageFinished: (String url) {
                  if (url ==
                      '${ApiMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    Navigator.pop(context);
                  }
                },
                //  javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
                javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
              )
            : const Center(child: CircularProgressIndicator()),
      ),
    );
  }

  void reloadWebView() {
    _webViewController.reload();
  }
}
